@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/attr.c,v 1.6 2005/01/15 00:23:22 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/attr.c,v 1.9 2006/02/10 23:21:18 william Exp $
  */
 
 #define _INCLUDE_FROM_ATTR_C_
@@ -668,6 +668,24 @@ int ReadAttr(FP, AttrPtr)
    return FreeBufAndReturn(line, TRUE);
 }
 
+struct ObjRec *FindTopLevelObjWithType(type_str)
+   char *type_str;
+{
+   struct ObjRec *obj_ptr=NULL;
+
+   for (obj_ptr=botObj; obj_ptr != NULL; obj_ptr=obj_ptr->prev) {
+      struct AttrRec *attr_ptr=NULL;
+
+      for (attr_ptr=obj_ptr->fattr; attr_ptr != NULL; attr_ptr=attr_ptr->next) {
+         if (strcmp(attr_ptr->attr_name.s, "type=") == 0 &&
+               strcmp(attr_ptr->attr_value.s, type_str) == 0) {
+            return obj_ptr;
+         }
+      }
+   }
+   return NULL;
+}
+
 static
 int ObjMightChangeForShowAndUpdAttrNames(ObjPtr)
    struct ObjRec *ObjPtr;
@@ -2554,7 +2572,7 @@ int InitAttr()
    }
 #endif /* DEFATTRGROUP */
 #endif /* _TANGRAM_II */
-   if (maxAttrGroups >= 0) {
+   if (maxAttrGroups > 0) {
       gAttrGroupInfo = (AttrGroupInfo**)malloc(maxAttrGroups *
             sizeof(AttrGroupInfo*));
       if (gAttrGroupInfo == NULL) FailAllocMessage();
