@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/cmdids.h,v 1.3 2005/01/15 00:23:22 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/cmdids.h,v 1.8 2006/06/12 23:46:58 william Exp $
  */
 
 #ifndef _CMDIDS_H_
@@ -423,7 +423,14 @@
 #define CMDID_IMPORTPBMFILE           468
 #define CMDID_IMPORTPGMFILE           469
 #define CMDID_EDITATTRGROUPINEDITOR   470
+#define CMDID_LINKEXTJPEGFILE         471
+#define CMDID_NEXTSLIDE               472
+#define CMDID_PREVSLIDE               473
+#define CMDID_SETOBJSHADOWCOLOR       474
+#define CMDID_SETOBJSHADOWOFFSETS     475
+#define CMDID_ADDOBJSHADOW            476
+#define CMDID_REMOVEOBJSHADOW         477
 
-#define MAXCMDIDS 471
+#define MAXCMDIDS 478
 
 #endif /*_CMDIDS_H_*/
