@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/const.h,v 1.2 2005/01/15 00:23:22 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/const.h,v 1.4 2006/02/10 23:21:19 william Exp $
  */
 
 #ifndef _TGIF_CONST_H_
@@ -705,6 +705,13 @@
 #define XBM_EPS 1
 #define XBM_EPSI 2
 
+/* xpm real_type */
+
+#define XPM_XPM  0
+#define XPM_JPEG 1
+#define XPM_EPS  2 /* not implemented */
+#define XPM_EPSI 3 /* not implemented */
+
 /* cmd stuff */
 
 #define CMD_COMPOSITE     0
