@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/dup.c,v 1.2 2005/01/15 00:23:22 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/dup.c,v 1.5 2006/02/10 23:21:19 william Exp $
  */
 
 #define _INCLUDE_FROM_DUP_C_
@@ -620,6 +620,17 @@ void DupXPmObj(XPmPtr, ObjPtr)
    xpm_ptr->cached_bitmap = None;
    xpm_ptr->clip_mask = None;
 
+   xpm_ptr->real_type = XPmPtr->real_type;
+   xpm_ptr->linked_jpeg = FALSE;
+   xpm_ptr->filename = NULL;
+
+   if (xpm_ptr->real_type == XPM_JPEG) {
+      xpm_ptr->linked_jpeg = XPmPtr->linked_jpeg;
+      if (XPmPtr->filename != NULL) {
+         xpm_ptr->filename = UtilStrDup(XPmPtr->filename);
+         if (xpm_ptr->filename == NULL) FailAllocMessage();
+      }
+   }
    if (ObjPtr->ctm != NULL) {
       memcpy(&xpm_ptr->cached_ctm, &XPmPtr->cached_ctm,
             sizeof(struct XfrmMtrxRec));
