@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2003, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/group.c,v 1.2 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/group.c,v 1.4 2006/06/13 18:56:04 william Exp $
  */
 
 #define _INCLUDE_FROM_GROUP_C_
@@ -40,17 +40,16 @@
 
 int gnDeleteAttrsWhileUngrouping=FALSE;
 
-void CreateGroupObj(TopObjPtr, BotObjPtr)
-   struct ObjRec *TopObjPtr, *BotObjPtr;
+struct ObjRec *JustCreateGroupObj()
 {
-   struct GroupRec *group_ptr;
-   struct ObjRec *obj_ptr;
+   struct GroupRec *group_ptr=NULL;
+   struct ObjRec *obj_ptr=NULL;
 
    group_ptr = (struct GroupRec *)malloc(sizeof(struct GroupRec));
    if (group_ptr == NULL) FailAllocMessage();
    memset(group_ptr, 0, sizeof(struct GroupRec));
-   group_ptr->first = TopObjPtr;
-   group_ptr->last = BotObjPtr;
+   group_ptr->first = NULL;
+   group_ptr->last = NULL;
    group_ptr->rotate = ROTATE0;
    group_ptr->flip = NO_FLIP;
    group_ptr->deck_index = (-1);
@@ -59,11 +58,37 @@ void CreateGroupObj(TopObjPtr, BotObjPtr)
    obj_ptr = (struct ObjRec *)malloc(sizeof(struct ObjRec));
    if (obj_ptr == NULL) FailAllocMessage();
    memset(obj_ptr, 0, sizeof(struct ObjRec));
-   obj_ptr->x = selObjLtX; /* note:  selLtX, selLtY are absolute */
-   obj_ptr->y = selObjLtY;
+   obj_ptr->x = 0;
+   obj_ptr->y = 0;
    obj_ptr->id = objId++;
    obj_ptr->locked = FALSE;
    obj_ptr->type = OBJ_GROUP;
+   obj_ptr->bbox.ltx = 0;
+   obj_ptr->bbox.lty = 0;
+   obj_ptr->bbox.rbx = 0;
+   obj_ptr->bbox.rby = 0;
+   obj_ptr->obbox.ltx = 0;
+   obj_ptr->obbox.lty = 0;
+   obj_ptr->obbox.rbx = 0;
+   obj_ptr->obbox.rby = 0;
+   obj_ptr->detail.r = group_ptr;
+   obj_ptr->fattr = obj_ptr->lattr = NULL;
+   obj_ptr->ctm = NULL;
+   obj_ptr->invisible = FALSE;
+
+   return obj_ptr;
+}
+
+void CreateGroupObj(TopObjPtr, BotObjPtr)
+   struct ObjRec *TopObjPtr, *BotObjPtr;
+{
+   struct ObjRec *obj_ptr=JustCreateGroupObj();
+   struct GroupRec *group_ptr=obj_ptr->detail.r;
+
+   group_ptr->first = TopObjPtr;
+   group_ptr->last = BotObjPtr;
+   obj_ptr->x = selObjLtX; /* note:  selLtX, selLtY are absolute */
+   obj_ptr->y = selObjLtY;
    obj_ptr->bbox.ltx = selLtX;
    obj_ptr->bbox.lty = selLtY;
    obj_ptr->bbox.rbx = selRbX;
@@ -72,10 +97,6 @@ void CreateGroupObj(TopObjPtr, BotObjPtr)
    obj_ptr->obbox.lty = selObjLtY;
    obj_ptr->obbox.rbx = selObjRbX;
    obj_ptr->obbox.rby = selObjRbY;
-   obj_ptr->detail.r = group_ptr;
-   obj_ptr->fattr = obj_ptr->lattr = NULL;
-   obj_ptr->ctm = NULL;
-   obj_ptr->invisible = FALSE;
    if (numObjLocked > 0) obj_ptr->locked = TRUE;
    AddObj(NULL, topObj, obj_ptr);
 }
