@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/mainloop.c,v 1.7 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/mainloop.c,v 1.11 2006/06/06 00:20:53 william Exp $
  */
 
 #define _INCLUDE_FROM_MAINLOOP_C_
@@ -101,11 +101,9 @@
 #include "xpixmap.e"
 #include "xprtfltr.e"
 
-#ifndef USE_XAPPLRESDIR
 #ifdef USE_XT_INITIALIZE
 Widget		toplevel=(Widget)0;
 #endif /* USE_XT_INITIALIZE */
-#endif /* ~USE_XAPPLRESDIR */
 
 int	x11R6OrAbove=FALSE;
 int	origArgC=0;
@@ -140,9 +138,6 @@ PageInfo	mergingPageInfo;
 
 static int	maxExtraWins=0;
 static int	quitDraw=TRUE;
-#ifdef USE_XAPPLRESDIR
-static char	*xEnvStr=NULL;
-#endif /* USE_XAPPLRESDIR */
 
 static int	useXlib=FALSE;
 
@@ -425,20 +420,11 @@ void ExposeEventHandler(input, recursive)
       while (XCheckWindowEvent(mainDisplay, choiceWindow, ExposureMask, &ev)) ;
       RedrawChoiceWindow();
    } else if (input->xany.window == drawWindow) {
-#ifdef ICCCM_TEST
-static int n=0;
-#endif /* ICCCM_TEST */
       while (XCheckWindowEvent(mainDisplay, drawWindow, ExposureMask, &ev)) ;
       if (topSel != NULL || curChoice==VERTEXMODE || SomethingDirty() ||
             showCrossHair) {
-#ifdef ICCCM_TEST
-fprintf(stderr, "[%1d] ExposeEventHandler(A)\n", n++);
-#endif /* ICCCM_TEST */
          ClearAndRedrawDrawWindow();
       } else {
-#ifdef ICCCM_TEST
-fprintf(stderr, "[%1d] ExposeEventHandler(B)\n", n++);
-#endif /* ICCCM_TEST */
          RedrawDrawWindow(botObj);
          RedrawCurText();
       }
@@ -725,7 +711,6 @@ void InitLocale()
             }
          }
       } else {
-#ifndef USE_XAPPLRESDIR
 #ifdef USE_XT_INITIALIZE
          if (XtSetLanguageProc(NULL, NULL, NULL) == NULL) {
             fprintf(stderr, "%s\n",
@@ -733,7 +718,6 @@ void InitLocale()
             MySetLocale(LC_ALL, "C");
          }
 #endif /* USE_XT_INITIALIZE */
-#endif /* ~USE_XAPPLRESDIR */
       }
    }
    MySetLocale(LC_ALL, NULL);
@@ -1103,15 +1087,16 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
    char *pszFile;
    int *pnNeedToCheckAutoExec;
 {
-   char *c_ptr=NULL;
    int cannot_opendisplay=FALSE, allow_open=TRUE;
+
+#ifdef USE_XT_INITIALIZE
+   useXlib = cmdLineUseXlib;
+#else /* ~USE_XT_INITIALIZE */
 #ifdef USE_XAPPLRESDIR
    FILE *xenv_fp=NULL;
-   char tmp_buf[MAXPATHLENGTH+1];
+   char *c_ptr=NULL, *xEnvStr=NULL, tmp_buf[MAXPATHLENGTH+1];
    int len=0;
-#endif /* USE_XAPPLRESDIR */
 
-#ifdef USE_XAPPLRESDIR
 #ifdef XAPPLOADDIR_DEF
    if (getenv("XENVIRONMENT") == NULL) {
       if (((c_ptr=getenv("XAPPLRESDIR")) == NULL)) {
@@ -1148,12 +1133,7 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
          }
       }
    }
-   if ((mainDisplay=XOpenDisplay(displayName)) == 0)
-#else /* ~USE_XAPPLRESDIR */
-   c_ptr = NULL;
-#ifdef USE_XT_INITIALIZE
-   useXlib = cmdLineUseXlib;
-#else /* ~USE_XT_INITIALIZE */
+#endif /* USE_XAPPLRESDIR */
    useXlib = TRUE;
 #endif /* USE_XT_INITIALIZE */
    if (useXlib) {
@@ -1166,7 +1146,6 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
             (mainDisplay=XtDisplay(toplevel)) == 0);
 #endif /* USE_XT_INITIALIZE */
    }
-#endif /* USE_XAPPLRESDIR */
    if (cannot_opendisplay) {
       if (displayName == NULL) {
          fprintf(stderr, "%s\n", TgLoadString(STID_CANT_OPEN_DISPLAY_ABORT));
@@ -1261,9 +1240,18 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
       }
    }
    if (cmdLineMerge && cmdLineMergeArgc > 0 && cmdLineMergeArgv != NULL) {
-      int arg_index=0, abort_merge=FALSE;
+      int arg_index=0, abort_merge=FALSE, num_argc=cmdLineMergeArgc;
+      int identical=FALSE;
+      char **ppsz_html_export_template=(char**)malloc(cmdLineMergeArgc*
+            sizeof(char*));
+
+      if (ppsz_html_export_template == NULL) FailAllocMessage();
+      memset(ppsz_html_export_template, 0, cmdLineMergeArgc*sizeof(char*));
 
       if (JustLoadAFile(cmdLineMergeArgv[0], NULL, TRUE, &abort_merge)) {
+         ppsz_html_export_template[0] = UtilStrDup(gszHhtmlExportTemplate);
+         if (ppsz_html_export_template[0] == NULL) FailAllocMessage();
+
          if (!abort_merge) {
             PageInfo pi;
 
@@ -1284,6 +1272,11 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
                      NULL)) {
                   break;
                }
+               ppsz_html_export_template[arg_index] =
+                     UtilStrDup(gszHhtmlExportTemplate);
+               if (ppsz_html_export_template[arg_index] == NULL) {
+                  FailAllocMessage();
+               }
                CleanUpComments();
 
                firstPage->prev = pi.last_page;
@@ -1317,6 +1310,30 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
       CleanUpMergeArgs();
       ClearFileInfo(FALSE);
       SetFileModified(TRUE);
+
+      identical = TRUE;
+      for (arg_index=1; arg_index < num_argc; arg_index++) {
+         if (strcmp(ppsz_html_export_template[0],
+               ppsz_html_export_template[arg_index]) != 0) {
+            identical = FALSE;
+            break;
+         }
+      }
+      if (!identical) {
+         UtilStrCpyN(gszMsgBox, sizeof(gszMsgBox),
+               TgLoadString(STID_NO_HTML_TEMPLATE_FILE));
+         Msg(gszMsgBox);
+      } else if (*ppsz_html_export_template[0] != '\0') {
+         UtilStrCpyN(gszHhtmlExportTemplate, sizeof(gszHhtmlExportTemplate),
+            ppsz_html_export_template[0]);
+         sprintf(gszMsgBox, TgLoadString(STID_HTML_TEMPLATE_SET_TO_GIVEN),
+               gszHhtmlExportTemplate);
+         Msg(gszMsgBox);
+      }
+      for (arg_index=0; arg_index < num_argc; arg_index++) {
+         UtilFree(ppsz_html_export_template[arg_index]);
+      }
+      free(ppsz_html_export_template);
    } else if (*pszFile != '\0') {
       JustLoadAFile(pszFile, pnNeedToCheckAutoExec, FALSE, NULL);
    } else {
@@ -1715,12 +1732,10 @@ void MainLoop(Op, FileName, FuncStr, Str1, Menu1, Str2, Menu2, Str3, Menu3)
          XCloseDisplay(mainDisplay);
          mainDisplay = NULL;
       } else {
-#ifndef USE_XAPPLRESDIR
 #ifdef USE_XT_INITIALIZE
          XtDestroyWidget(toplevel);
          toplevel = (Widget)0;
 #endif /* USE_XT_INITIALIZE */
-#endif /* ~USE_XAPPLRESDIR */
       }
       exitNormally = TRUE;
       AllocStrings(FuncStr, Str1, Menu1, Str2, Menu2, Str3, Menu3);
