@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/mainmenu.c,v 1.2 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/mainmenu.c,v 1.4 2006/02/10 23:21:20 william Exp $
  */
 
 #define _INCLUDE_FROM_MAINMENU_C_
@@ -1105,12 +1105,16 @@ void HidePopupMenusForSlideShow()
       ClearObjCachesInAllPages();
       if (adj_caches) { ShowZoom(); }
    }
+#ifndef NOKDE3BUG
+   XMoveResizeWindow(mainDisplay, mainWindow, 0, 0,
+         dpy_w+gaPopupCoords[MAXMENUS+2].x-draw_win_w+2,
+         dpy_h+gaPopupCoords[MAXMENUS+2].y-draw_win_h+2);
+#endif /* ~NOKDE3BUG */
    XMoveResizeWindow(mainDisplay, mainWindow,
          gaPopupCoords[MAXMENUS+1].x-draw_win_x-1,
          gaPopupCoords[MAXMENUS+1].y-draw_win_y-1,
          dpy_w+gaPopupCoords[MAXMENUS+2].x-draw_win_w+2,
          dpy_h+gaPopupCoords[MAXMENUS+2].y-draw_win_h+2);
-
 }
 
 void ShowPopupMenusForSlideShow()
