@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.3 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.9 2006/06/12 23:59:07 william Exp $
  */
 
 #define _INCLUDE_FROM_MENUINFO_C_
@@ -201,6 +201,23 @@ TgMenuInfo stretchableTextModeMenuInfo={ TGMUTYPE_BITMAP,
                                          stretchableTextModeMenuItemInfo,
                                          CreateStretchableTextModeMenu };
 
+static TgMenuItemInfo objShadowMenuItemInfo[] = {
+   { N_("Set Object Shadow Color..."), NULL,
+     N_("Set the shadow color to be used for creating object shadows"), NULL,
+     CMDID_SETOBJSHADOWCOLOR },
+   { N_("Set Object Shadow Offsets..."), NULL,
+     N_("Set the x and y offset for generic object shadow"), NULL,
+     CMDID_SETOBJSHADOWOFFSETS },
+   { N_("Add Object Shadow"), NULL,
+     N_("Add shadows to selected objects"), NULL, CMDID_ADDOBJSHADOW },
+   { N_("Remove Object Shadow"), NULL,
+     N_("Remove shadows from selected objects"), NULL, CMDID_REMOVEOBJSHADOW },
+   { NULL, NULL, NULL, NULL, INVALID }
+};
+static TgMenuInfo objShadowMenuInfo={ TGMUTYPE_TEXT,
+                                      objShadowMenuItemInfo,
+                                      TgCreateMenuFromMenuInfo };
+
 TgMenuInfo shapeMenuInfo={ TGMUTYPE_BITMAP, NULL, CreateShapeMenu };
 
 static TgMenuItemInfo pageLayoutMenuItemInfo[] = {
@@ -550,6 +567,9 @@ static TgMenuItemInfo importMenuItemInfo[] = {
    { N_("Embed EPS File..."), NULL, N_("Embed/Import a PS/EPS file"), NULL,
      CMDID_EMBEDEPSFILE },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Link External JPEG File..."), NULL,
+     N_("Link to an external JPEG file"), NULL, CMDID_LINKEXTJPEGFILE },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Auto EPS Preview Bitmap"), NULL,
      N_("Auto-generate a preview bitmap for a PS/EPS file when embedding/importing it (if it does not have one already)."), NULL,
      CMDID_TOGGLEAUTOEPSPREVIEWBITMAP },
@@ -924,6 +944,8 @@ static TgMenuItemInfo editMenuItemInfo[] = {
      N_("Select a file and paste the content as text"), NULL,
      CMDID_PASTEFROMFILE },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Generic Object Shadow"), TGMUITEM_SUBMENU,
+     N_("Generic Object Shadow submenu >>>"), &objShadowMenuInfo, INVALID },
    { N_("Shape"), TGMUITEM_PINNABLESUBMENU,
      N_("Shape submenu >>>"), &shapeMenuInfo, MENU_SHAPE },
    { N_("Set Shape Shadow..."), NULL, N_("Specify the shadow for shapes"), NULL,
@@ -1169,8 +1191,16 @@ static TgMenuItemInfo slideShowModeMenuItemInfo[] = {
      N_("Go into freehand drawing mode in slideshow"), NULL,
      CMDID_FREEHANDMODEINSLIDESHOW },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Next Slide"), NULL, N_("Go to next slide"), NULL,
+     CMDID_NEXTPAGE },
+   { N_("Prev Slide"), NULL, N_("Go to previous slide"), NULL,
+     CMDID_PREVPAGE },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Color"), TGMUITEM_PINNABLESUBMENU,
      N_("Color Menu"), &colorMenuInfo, MENU_COLOR },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Exit Slide Show Mode"), "Esc", N_("Exit SlideShow mode"), NULL,
+     CMDID_TOGGLESLIDESHOW },
    { NULL, NULL, NULL, NULL, INVALID }
 };
 TgMenuInfo slideShowModeMenuInfo={ TGMUTYPE_TEXT, slideShowModeMenuItemInfo,
