@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2003, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/msg.c,v 1.10 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/msg.c,v 1.18 2006/06/12 22:04:33 william Exp $
  */
 
 #define _INCLUDE_FROM_MSG_C_
@@ -1376,6 +1376,7 @@ int EmergencySaveForXCont(s)
    if (exitNormally) return 0;
 
    if (copyingToCutBuffer) {
+      emergencyCount--;
       copyingToCutBuffer = INVALID;
       return 0;
    }
@@ -1510,6 +1511,8 @@ void Usage(tool_name)
    fprintf(stdout, "\t[-usexlib] \\\n");
    fprintf(stdout, "\t[-listdontreencode] \\\n");
    fprintf(stdout, "\t[-version | --version] \\\n");
+   fprintf(stdout, "\t[-pdfspd | -pdfspd=true | -pdfspd=false] \\\n");
+   fprintf(stdout, "\t[-pssetup \"<string>\"] \\\n");
    fprintf(stdout, "\t[-nomode] \\\n");
 #if defined(_TANGRAM_II) || defined(_TGIF_WB2)
    fprintf(stdout, "\t[-parent <parent_window_id>] \\\n");
@@ -1539,15 +1542,17 @@ void Usage(tool_name)
          "\t[-dontreencode=\"<%s>:<%s>:...\" | -listdontreencode] \\\n",
          "fontfamily", "fontfamily");
    fprintf(stdout, "\t[-version | --version | -justversion] \\\n");
-   fprintf(stdout, "\t[-pdfspd | -pdfspd=true | -pdfspd=false] \\\n");
    fprintf(stdout, "\t[-producedby=\"<string>\"] \\\n");
    fprintf(stdout, "\t[-page <number>] \\\n");
    fprintf(stdout, "\t[-print_cmd \"<command>\"] \\\n");
    fprintf(stdout, "\t[-one_file_per_page] \\\n");
    fprintf(stdout, "\t[-pepsc] \\\n");
    fprintf(stdout, "\t[-pdfspd | -pdfspd=true | -pdfspd=false] \\\n");
+   fprintf(stdout, "\t[-pssetup \"<string>\"] \\\n");
+   fprintf(stdout, "\t[-j2p6_cmd \"<command>\"] \\\n");
    fprintf(stdout, "\t[-dontcondense | -condensed] \\\n");
    fprintf(stdout, "\t[-a4] \\\n");
+   fprintf(stdout, "\t[-noshowpageineps] \\\n");
    fprintf(stdout, "\t[-quiet] \\\n");
    fprintf(stdout, "\t[-bop_hook \"<string>\"] \\\n");
    fprintf(stdout, "\t[-eop_hook \"<string>\"] \\\n");
@@ -1570,6 +1575,7 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
    *cmdLineTmpFileModeStr = '\0';
    *cmdLineGenParser = '\0';
    *cmdLineFileToExec = '\0';
+   *cmdLineJpegToPpm6Cmd = '\0';
    cmdLineOneFilePerPage = FALSE;
    *outputDir = '\0';
    for (argc--, argv++; argc > 0; argc--, argv++) {
@@ -1770,12 +1776,24 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
                      "-pdfspd", tmp_str);
                fprintf(stderr, "\n");
             }
+         } else if (strcmp(*argv, "-pssetup") == 0) {
+            argc--; argv++;
+            if (argc <= 0) {
+               fprintf(stderr, TgLoadString(STID_MISSING_ARG_FOR_CMDLINE_OPT),
+                     "-pssetup");
+               fprintf(stderr, "\n");
+               Usage(progName);
+            }
+            cmdLinePsSetup = TRUE;
+            SetPsSetup(*argv);
          } else if (strcmp(*argv, "-dontcondense") == 0) {
             SetCmdLineDontCondense();
          } else if (strcmp(*argv, "-condensed") == 0) {
             SetCmdLineCondensedPS();
          } else if (strcmp(*argv, "-a4") == 0) {
             cmdLineA4 = TRUE;
+         } else if (strcmp(*argv, "-noshowpageineps") == 0) {
+            cmdLineNoShowPageInEPS = TRUE;
          } else if (strcmp(*argv, "-quiet") == 0) {
             cmdLineQuiet = TRUE;
          } else if (strcmp(*argv, "-bop_hook") == 0) {
@@ -1930,6 +1948,34 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
             } else {
                strcpy(printCommand, *argv);
             }
+         } else if (strcmp(*argv, "-j2p6_cmd") == 0) {
+            argc--; argv++;
+            if (argc <= 0) {
+               fprintf(stderr, TgLoadString(STID_MISSING_ARG_FOR_CMDLINE_OPT),
+                     "-j2p6_cmd");
+               fprintf(stderr, "\n");
+               Usage(progName);
+            }
+            len = strlen(*argv);
+            if (**argv == '"' && (*argv)[len-1] == '"') {
+               if (len-3 >= MAXSTRING) {
+                  fprintf(stderr, TgLoadString(STID_CMDLINE_ARG_GIVEN_TOO_LONG),
+                        "-j2p6_cmd");
+                  fprintf(stderr, "\n");
+               } else {
+                  strcpy(cmdLineJpegToPpm6Cmd, &(*argv)[1]);
+                  cmdLineJpegToPpm6Cmd[strlen(cmdLineJpegToPpm6Cmd)-1] = '\0';
+               }
+            } else {
+               if (len-1 >= MAXSTRING) {
+                  fprintf(stderr, TgLoadString(STID_CMDLINE_ARG_GIVEN_TOO_LONG),
+                        "-j2p6_cmd");
+                  fprintf(stderr, "\n");
+               } else {
+                  strcpy(cmdLineJpegToPpm6Cmd, *argv);
+                  cmdLineJpegToPpm6Cmd[strlen(cmdLineJpegToPpm6Cmd)-1] = '\0';
+               }
+            }
          } else if (strncmp(*argv, "-o", 2) == 0) {
             strcpy(outputDir, &(*argv)[2]);
          } else if (strcmp(*argv, "-prtgif") != 0 &&
@@ -2145,6 +2191,16 @@ int ProcessTgifOptions(argc, argv, file_name, name_sz)
                   "-pdfspd", tmp_str);
             fprintf(stderr, "\n");
          }
+      } else if (strcmp(*argv, "-pssetup") == 0) {
+         argc--; argv++;
+         if (argc <= 0) {
+            fprintf(stderr, TgLoadString(STID_MISSING_ARG_FOR_CMDLINE_OPT),
+                  "-pssetup");
+            fprintf(stderr, "\n");
+            Usage(progName);
+         }
+         cmdLinePsSetup = TRUE;
+         SetPsSetup(*argv);
       } else if (argv[i][0] == '=') {
          strcpy(geometrySpec, argv[i]);
          geometrySpecified = TRUE;
@@ -2167,7 +2223,17 @@ int ProcessTgifOptions(argc, argv, file_name, name_sz)
             UtilStrCpyN(file_name, name_sz, argv[i]);
          }
       } else {
+#ifndef USE_XT_INITIALIZE
          Usage(progName);
+#else /* USE_XT_INITIALIZE */
+         if (strcmp(argv[i], "-xrm") == 0) {
+            if (++i == argc) {
+               fprintf(stderr, TgLoadString(STID_MISSING_ARG_FOR_CMDLINE_OPT),
+                     "-xrm");
+               fprintf(stderr, "\n");
+            }
+         }
+#endif /* ~USE_XT_INITIALIZE */
       }
    }
    return TRUE;
