@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/navigate.c,v 1.3 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/navigate.c,v 1.9 2006/02/10 23:21:20 william Exp $
  */
 
 #define _INCLUDE_FROM_NAVIGATE_C_
@@ -36,6 +36,7 @@
 #include "tgifdefs.h"
 #include "cmdids.h"
 
+#include "attr.e"
 #include "auxtext.e"
 #include "button.e"
 #include "choice.e"
@@ -46,6 +47,7 @@
 #include "cutpaste.e"
 #include "dialog.e"
 #include "drawing.e"
+#include "exec.e"
 #include "file.e"
 #include "font.e"
 #include "mainloop.e"
@@ -1288,6 +1290,56 @@ void ToggleHyperSpace(KeepSelected)
    RedrawDummyWindow1();
 }
 
+void NextSlide()
+{
+   struct ObjRec *obj_ptr=FindTopLevelObjWithType("page_defaultplay");
+
+   if (obj_ptr != NULL) {
+      struct AttrRec *exec_attr=FindObjAttrWithName(obj_ptr, "exec=");
+      struct AttrRec *attr_ptr=FindObjAttrWithName(obj_ptr, "finished=");
+
+      if (exec_attr != NULL && attr_ptr != NULL) {
+         char *attr_value=attr_ptr->attr_value.s;
+
+         if (strcmp(attr_value, "0") == 0) {
+            DoExecLoop(obj_ptr, exec_attr);
+            /*
+             * if (!userAbortExec) {
+             *    ReplaceAttrFirstValue(obj_ptr, attr_ptr, "1");
+             * }
+             */
+            return;
+         }
+      }
+   }
+   NextPage();
+}
+
+void PrevSlide()
+{
+   struct ObjRec *obj_ptr=FindTopLevelObjWithType("page_defaultrewind");
+
+   if (obj_ptr != NULL) {
+      struct AttrRec *exec_attr=FindObjAttrWithName(obj_ptr, "exec=");
+      struct AttrRec *attr_ptr=FindObjAttrWithName(obj_ptr, "finished=");
+
+      if (exec_attr != NULL && attr_ptr != NULL) {
+         char *attr_value=attr_ptr->attr_value.s;
+
+         if (strcmp(attr_value, "0") == 0) {
+            DoExecLoop(obj_ptr, exec_attr);
+            /*
+             * if (!userAbortExec) {
+             *    ReplaceAttrFirstValue(obj_ptr, attr_ptr, "1");
+             * }
+             */
+            return;
+         }
+      }
+   }
+   PrevPage();
+}
+
 struct SlideShowInfoRec {
    int saved_in_hyperspace;
    int saved_fill, saved_pen;
