@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/polygon.c,v 1.2 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/polygon.c,v 1.5 2006/02/10 23:21:20 william Exp $
  */
 
 #define _INCLUDE_FROM_POLYGON_C_
@@ -599,6 +599,8 @@ void DoPolygonMeasureCursor(start, num_pts, x, y, dx, dy, erase, drag, closed)
    sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s\nangle=%s", w_buf, h_buf, x_buf, y_buf,
          a_buf);
 
+   x = OFFSET_X(x);
+   y = OFFSET_Y(y);
    switch (start) {
    case POLYGON_STARTSHOW: StartShowMeasureCursor(x, y, buf, TRUE); break;
    case POLYGON_DOSHOW: ShowMeasureCursor(x, y, buf, TRUE); break;
@@ -658,10 +660,11 @@ void ContinuePolygon(OrigX, OrigY)
       TgLoadCachedString(CSTID_CLOSE_POLYGON_SPLINE));
    DoPolygonMeasureCursor(POLYGON_STARTSHOW, num_pts, ABS_X(grid_x),
          ABS_Y(grid_y), 0, 0, POLYGON_DRAW, POLYGON_CLICK, closed);
-   XGrabPointer(mainDisplay, drawWindow, FALSE,
-         PointerMotionMask | ButtonPressMask,
-         GrabModeAsync, GrabModeAsync, None, handCursor, CurrentTime);
-   
+   if (!debugNoPointerGrab) {
+      XGrabPointer(mainDisplay, drawWindow, FALSE,
+            PointerMotionMask | ButtonPressMask,
+            GrabModeAsync, GrabModeAsync, None, handCursor, CurrentTime);
+   }
    while (!done) {
       XNextEvent(mainDisplay, &input);
 
