@@ -83,11 +83,11 @@ GLOBAL_OPTIONS rmcast_options =  {
     /*    char       dest_ip[IP_STRING_SIZE];  */
     { "225.1.2.3" } , 
     /*    int        dest_port; */
-    5000,
+    5151,
     /* int        ttl; */
     1,
     /* unsigned int        microsleep; */
-    2000,
+    10,
     /* int     hosts_identified; default 0*/
     0,
     /* int     timer_distribution; */
@@ -105,13 +105,13 @@ GLOBAL_OPTIONS rmcast_options =  {
     /* int        new_member_support; */
     0,
     /* int        statistics; */
-    1,
+    0,
     /* int        refresh_timer; */
     10,
     /* float      loss_prob; */
     0,
     /* int        leave_group_wait_time; */
-    1000000,
+    500000,
     /* int        rcv_buffer_size;         */
     10000,
     /* HOSTS_DELAYS hosts_delays */
@@ -259,7 +259,7 @@ void rmcastJoinGroup  (int soc, char *group_addr)
 void rmcastLeaveGroup  (int soc, char *group_addr)
 {
     
-    char *buffer;
+    BYTE *buffer;
     int buffsize = 0;
     
    
@@ -491,18 +491,16 @@ Time Snd/Rcv/Loss type sender_ip       sender_pid requested_ip    requested_pid
  *
  ******************************************************************************************************/
 
-
 void *rmcastReceivePackets(void *user_soc)
 {
     int soc = (int)user_soc;
     struct sockaddr_in sender;
-
-
     static int first = 1, first_pckts_lost = 10;
 
-    int	 len, sn;
-    int	 nbytes; /* number of bytes received */
-    char	 message[rmcast_options.rcv_buffer_size];
+    socklen_t len;
+    int sn;
+    int nbytes; /* number of bytes received */
+    char message[rmcast_options.rcv_buffer_size];
     PACKET_INFO pckt_info;
     MEMBER_ID aux_member_id;
 #ifdef DPROCESSING_TIME
@@ -512,9 +510,11 @@ void *rmcastReceivePackets(void *user_soc)
     char tipo;
 #endif
 
+    sn = 0;
+    
 #ifndef SOLARIS
     
-    sigset_t     alrmset;
+    sigset_t alrmset;
     
     sigfillset( &alrmset );            /* fills the alarm set with all the signals */
     
@@ -1010,7 +1010,7 @@ void	rmcastSendPacket(int soc, BYTE *message, int message_size)
         pthread_mutex_unlock(&change_local_user_sn);
     }
     
-    msgPcktUnmountMessage(&pckt_info, local_message);
+    msgPcktUnmountMessage(&pckt_info, (BYTE *)local_message);
     
     switch (pckt_info.type)
     {
@@ -1048,7 +1048,7 @@ void	rmcastSendPacket(int soc, BYTE *message, int message_size)
         msgPcktShowMessage(message);
 
         fprintf(stderr,"ERROR - rmcastSendPacket: exiting.\n");
-        exit(1);
+        exit( EXIT_FAILURE );
     }
     /* fprintf(stderr," Packet size RML: %d\n",message_size); FIXME teste pra saber o tamanho dos pacotes */
 
@@ -1131,6 +1131,7 @@ void *rmcastHandleSignals(void *arg)
                 fprintf(stderr,"rmcastHandleSignals: Signal %s received. Exiting.\n",strsignal(sig));
                 
                 RM_leaveGroup(local_user_info.socket, local_user_info.member_id.ip);
+                
             }
             else if (sig==SIGTSTP)
             {
@@ -1216,7 +1217,7 @@ void *rmcastHandleSignals(void *arg)
         fprintf(stderr,"DMUTEX rmcastHandleSignals: cache and event list UNLOCKED\n");
 #endif
     }
-    return (NULL);
+    return (0);
 }
 
 
@@ -1994,7 +1995,9 @@ void rmcastProcessRefreshPacket(PACKET_INFO pckt_info)
 int rmcastRemoveEvent(PACKET_INFO *packt, int event_type)
 {
     int retval; 	
-
+    
+    retval = 0;
+    
     switch (packt->type)
     {
         case    RETRANSM_PACKET_TYPE:
@@ -2077,7 +2080,7 @@ int rmcastFindEvent(PACKET_INFO *packt, int event_type)
         default:
         
             fprintf(stderr,"rmcastFindEvent ERROR: Not yet implemented event=%d packet_type=%d.\n",event_type,packt->type);
-            exit(1);
+            exit( EXIT_FAILURE );
     
     }
     
