@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/select.c,v 1.2 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/select.c,v 1.5 2006/02/10 23:21:21 william Exp $
  */
 
 #define _INCLUDE_FROM_SELECT_C_
@@ -1543,10 +1543,14 @@ void KeyPressInSelect(key_ev)
          return;
       }
       switch (key_sym) {
-      case XK_Left: PrevPage(); return;
-      case XK_KP_Left: PrevPage(); return;
-      case XK_Right: NextPage(); return;
-      case XK_KP_Right: NextPage(); return;
+      case XK_Left: PrevSlide(); return;
+      case XK_KP_Left: PrevSlide(); return;
+      case XK_Up: PrevSlide(); return;
+      case XK_KP_Up: PrevSlide(); return;
+      case XK_Right: NextSlide(); return;
+      case XK_KP_Right: NextSlide(); return;
+      case XK_Down: NextSlide(); return;
+      case XK_KP_Down: NextSlide(); return;
       default: break;
       }
    }
@@ -2176,6 +2180,9 @@ void Teleport(button_ev)
 
    if ((obj_ptr=FindAnObj(button_ev->x,button_ev->y,&owner_obj,NULL,NULL)) ==
          NULL) {
+      if (inSlideShow) {
+         NextSlide();
+      }
       return;
    }
    if (owner_obj != NULL) obj_ptr = owner_obj;
@@ -2220,6 +2227,10 @@ void Teleport(button_ev)
       return;
    }
    exec_attr = FindAttrWithName(obj_ptr, EXEC_ATTR, NULL);
+   if (exec_attr == NULL && inSlideShow) {
+      NextSlide();
+      return;
+   }
    DoExecLoop(obj_ptr, exec_attr);
 }
 
