@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/setup.c,v 1.11 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/setup.c,v 1.20 2006/06/06 00:20:53 william Exp $
  */
 
 #define _INCLUDE_FROM_SETUP_C_
@@ -224,6 +224,8 @@ int	zoomedIn = FALSE;
 struct BBRec	drawWinBBox;
 
 int	colorDisplay = FALSE;
+int	fullTrueColorMode = FALSE;
+int	noAntiAlias = TRUE;
 int	threeDLook = FALSE;
 int	fileModified = FALSE;
 int	objId = 0;
@@ -275,11 +277,12 @@ int	canvasWindowOnly=FALSE;
 int	talkToSelfFiledesInitialized=FALSE;
 int	talkToSelfFiledes[2];
 
+Atom	compoundTextAtom=(Atom)0;
+Atom	textAtom=(Atom)0;
+
 static Atom	wmDeleteWindowAtom=(Atom)0;
+static Atom	targetsAtom=(Atom)0;
 static Atom	utf8StringAtom=(Atom)0;
-static Atom	compoundTextAtom=(Atom)0;
-static Atom	textAtom=(Atom)0;
-static Atom	stringAtom=(Atom)0;
 
 static int	baseScrollBarW=SCROLLBAR_W;
 
@@ -668,23 +671,24 @@ int TgIsCmdEvent(pXEv)
    return FALSE;
 }
 
-#ifdef ICCCM_TEST
-static
 void HandleSelectionRequest(input)
    XEvent *input;
 {
-   static int id=0;
-   Window      requestor=input->xselectionrequest.requestor;
-   Atom        property=(Atom)0, target=(Atom)0, selection=(Atom)0;
+   Window requestor=(Window)0;
+   Atom property=(Atom)0, target=(Atom)0, selection=(Atom)0;
+   XEvent sent_ev;
 
+   requestor = input->xselectionrequest.requestor;
    selection = input->xselectionrequest.selection;
    target = input->xselectionrequest.target;
    property = input->xselectionrequest.property;
 
-   printf("\n%1d: SelectionRequest.\n", ++id);
+#ifdef NOT_DEFINED
+   {
+      static int id=0;
+      char *atom_name=NULL;
 
-   if (property != None) {
-      char     *atom_name=NULL;
+      printf("\n%1d: SelectionRequest.\n", ++id);
 
       atom_name = XGetAtomName(mainDisplay, property);
       printf("%1d: Property name is '%s'.\n", id, atom_name);
@@ -693,36 +697,42 @@ void HandleSelectionRequest(input)
       atom_name = XGetAtomName(mainDisplay, target);
       printf("%1d: Target name is '%s'.\n", id, atom_name);
       XFree(atom_name);
-   } else {
-      property = target;
    }
-   if (input->xselectionrequest.owner == mainWindow) {
-      printf("%1d: owner == mainWindow!\n", id);
-   } else {
-      XEvent      sent_ev;
+#endif /* NOT_DEFINED */
+   memset(&sent_ev, 0, sizeof(XEvent));
 
-      memset(&sent_ev, 0, sizeof(XEvent));
+   sent_ev.xselection.type = SelectionNotify;
+   sent_ev.xselection.display = mainDisplay;
+   sent_ev.xselection.requestor = requestor;
+   sent_ev.xselection.selection = selection;
+   sent_ev.xselection.time = input->xselectionrequest.time;
+   sent_ev.xselection.target = target;
+   sent_ev.xselection.property = None;
 
-      sent_ev.xselectionrequest.type = SelectionNotify;
-      sent_ev.xselectionrequest.display = mainDisplay;
-      sent_ev.xselectionrequest.requestor = mainWindow;
-      sent_ev.xselectionrequest.selection = selection;
-      sent_ev.xselectionrequest.time = input->xselectionrequest.time;
-      sent_ev.xselectionrequest.target = target;
-      sent_ev.xselectionrequest.property = property;
+   if (target == targetsAtom) {
+      Atom targets[2];
 
-      sent_ev.xselectionrequest.send_event = True;
-      sent_ev.xselectionrequest.owner = requestor;
+      targets[0] = XA_STRING;
+      targets[1] = compoundTextAtom;
+      targets[2] = textAtom;
+      XChangeProperty(mainDisplay, requestor, property, target, 32,
+            PropModeReplace, (unsigned char *)targets, 3);
+   } else if (target == XA_STRING || target == textAtom) {
+      XChangeProperty(mainDisplay, requestor, property, target, 8,
+            PropModeReplace, (unsigned char *)(dsCutBuffer.s), dsCutBuffer.sz);
+      sent_ev.xselection.property = property;
+   } else if (target == compoundTextAtom) {
+      XTextProperty text_property;
 
-/*       if (target == utf8StringAtom || target == compoundTextAtom ||
-            target == textAtom || target == stringAtom) {
-      } else {
-         sent_ev.xselectionrequest.property = None;
-      } */
-      XSendEvent(mainDisplay,requestor,False,NoEventMask,&sent_ev);
+      XmbTextListToTextProperty(mainDisplay, &(dsCutBuffer.s), 1,
+            XCompoundTextStyle, &text_property);
+      XChangeProperty(mainDisplay, requestor, property, target,
+            text_property.format, PropModeReplace, text_property.value,
+            text_property.nitems);
+      sent_ev.xselection.property = property;
    }
+   XSendEvent(mainDisplay, requestor, False, NoEventMask, &sent_ev);
 }
-#endif /* ICCCM_TEST */
 
 static XComposeStatus c_stat;
 
@@ -746,16 +756,14 @@ int mainWinEventHandler(input)
          return INVALID;
       }
       switch (key_sym) {
-      case XK_Left: PrevPage(); return INVALID;
-      case XK_KP_Left: PrevPage(); return INVALID;
-      case XK_Right: NextPage(); return INVALID;
-      case XK_KP_Right: NextPage(); return INVALID;
+      case XK_Left: PrevSlide(); return INVALID;
+      case XK_KP_Left: PrevSlide(); return INVALID;
+      case XK_Right: NextSlide(); return INVALID;
+      case XK_KP_Right: NextSlide(); return INVALID;
       default: break;
       }
    } else if (input->type == SelectionRequest) {
-#ifdef ICCCM_TEST
       HandleSelectionRequest(input);
-#endif /* ICCCM_TEST */
       return INVALID;
    } else if (input->type == UnmapNotify) {
       Iconify();
@@ -1016,6 +1024,30 @@ void InitTmpDir()
    }
 }
 
+static
+int InitAntiAlias()
+   /*
+    * Get here because fullTrueColorMode is TRUE.  So, by default, we
+    *         will use antialiased fonts, unless Tgif.NoAntialias is set
+    *         to TRUE.
+    * Need to add code to talk to the xft server.
+    */
+{
+#ifdef NOT_DEFINED
+   char *c_ptr=NULL;
+
+   noAntiAlias = FALSE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "NoAntialias")) !=
+         NULL && UtilStrICmp(c_ptr, "true") == 0) {
+      noAntiAlias = TRUE;
+   }
+#endif /* NOT_DEFINED */
+   /*
+    * Add code here to talk to the xft server.
+    */
+   return TRUE;
+}
+
 void Setup()
 {
    int bitmask=0, x_neg_in_def=FALSE, y_neg_in_def=FALSE;
@@ -1389,10 +1421,10 @@ void Setup()
    }
    /* do not translate -- program constants */
    wmDeleteWindowAtom = XInternAtom(mainDisplay, "WM_DELETE_WINDOW", False);
+   targetsAtom = XInternAtom(mainDisplay, "TARGETS", False);
    utf8StringAtom = XInternAtom(mainDisplay, "UTF8_STRING", False);
    compoundTextAtom = XInternAtom(mainDisplay, "COMPOUND_TEXT", False);
    textAtom = XInternAtom(mainDisplay, "TEXT", False);
-   stringAtom = XInternAtom(mainDisplay, "STRING", False);
    executeCmdByIDAtom = XInternAtom(mainDisplay, "TGIF_EXECUTE_CMD_BY_ID",
          False);
 
@@ -1606,7 +1638,21 @@ void Setup()
 
    colorDisplay = (cmdLineBW || DisplayPlanes(mainDisplay,mainScreen)==1 ||
          mainVisual->class==StaticGray) ? FALSE : TRUE;
-
+   fullTrueColorMode = FALSE;
+   if (colorDisplay && mainVisual->class == TrueColor) {
+#ifdef NOT_DEFINED
+      if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "UseCompatColorScheme")) !=
+            NULL && UtilStrICmp(c_ptr, "true") == 0) {
+         fullTrueColorMode = FALSE;
+      } else {
+         fullTrueColorMode = TRUE;
+      }
+#endif /* NOT_DEFINED */
+   }
+   noAntiAlias = TRUE;
+   if (fullTrueColorMode) {
+      InitAntiAlias();
+   }
    threeDLook = colorDisplay;
    if (threeDLook && (c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "3DLook")) !=
          NULL && UtilStrICmp(c_ptr, "false") == 0) {
