@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2003, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.5 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.13 2006/06/12 23:59:07 william Exp $
  */
 
 #define _INCLUDE_FROM_SHORTCUT_C_
@@ -23,11 +23,13 @@
 #include "tgifdefs.h"
 #include "cmdids.h"
 
+#include "choice.e"
 #include "msg.e"
 #include "setup.e"
 #include "shortcut.e"
 #include "strtbl.e"
 #include "tangram2.e"
+#include "util.e"
 
 /*
  * Note:  the num_args field in shortCutXlateTbl is used by the shortcut
@@ -111,7 +113,7 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { ';', META_ONLY,  "CutBit/Pixmap()", 0, CMDID_CUTBITPIXMAP },
    { '_', META_ONLY,  "AbutHorizontal()", 0, CMDID_ABUTHORIZONTAL },
    { '|', META_ONLY,  "AbutVertical()", 0, CMDID_ABUTVERTICAL },
-   { '#', META_ONLY,  "BreakUpText()", 0, CMDID_BREAKUPTEXT },
+   { '#', META_ONLY,  "BreakUpText()", 1, CMDID_BREAKUPTEXT },
    { '^', META_ONLY,  "ScrollToOrig()", 0, CMDID_SCROLLTOORIG },
    { '@', META_ONLY,  "ToggleMoveMode()", 0, CMDID_TOGGLEMOVEMODE },
    { '$', META_ONLY,  "SelectVertexMode()", 0, CMDID_SELECTVERTEXMODE },
@@ -424,6 +426,13 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { '\0', 0, "ImportPGMFile()", 0, CMDID_IMPORTPGMFILE },
    { '\0', 0, "EditIndexedAttrGroupInEditor()", 0,
                CMDID_EDITATTRGROUPINEDITOR },
+   { '\0', 0,  "LinkExtJPEGFile()", 0, CMDID_LINKEXTJPEGFILE },
+   { '\0', 0, "NextSlide()", 0, CMDID_NEXTSLIDE },
+   { '\0', 0, "PrevSlide()", 0, CMDID_PREVSLIDE },
+   { '\0', 0, "SetObjectShadowColor()", 0, CMDID_SETOBJSHADOWCOLOR },
+   { '\0', 0, "SetObjectShadowOffsets()", 0, CMDID_SETOBJSHADOWOFFSETS },
+   { '\0', 0, "AddObjectShadow()", 0, CMDID_ADDOBJSHADOW },
+   { '\0', 0, "RemoveObjectShadow()", 0, CMDID_REMOVEOBJSHADOW },
    { '\0', 0, "", 0, 0 }
 };
 
@@ -431,22 +440,56 @@ static int maxShortCuts=0;
 static int shortCutIndex[256];
 static char *shortCutArgs[256];
 
+typedef struct tagFuncKeyShortCutInfo {
+   char code;
+   unsigned int state;
+   char *name;
+   char *arg;
+} FuncKeyShortCutInfo;
+
+static FuncKeyShortCutInfo funcKeyInfo[13];
+
 static int shortCutCmdIdIndex[MAXCMDIDS-CMDID_BASE];
 
+static
+int FunctionKeySpec(buf, pn_code, pn_index_return)
+   char *buf;
+   int *pn_code, *pn_index_return;
+{
+   int value=0;
+   char *colon_ptr=strchr(buf, ':');
+
+   if (colon_ptr == NULL) return FALSE;
+   *colon_ptr = '\0';
+   if (buf[0] != 'F' || sscanf(&buf[1], "%d", &value) != 1) {
+      *colon_ptr = ':';
+      return FALSE;
+   }
+   *colon_ptr++ = ':';
+   if (value < 1 || value > 12) return FALSE;
+
+   *pn_code = value;
+   *pn_index_return = (int)(colon_ptr-buf);
+
+   return TRUE;
+}
+
 void InitShortCut()
 {
-   int i, num_cmdids=MAXCMDIDS-CMDID_BASE;
-   char *c_ptr;
+   int i=0, num_cmdids=MAXCMDIDS-CMDID_BASE;
+   char *c_ptr=NULL;
 
    for (i=0; i < 256; i++) {
       shortCutIndex[i] = INVALID;
       shortCutArgs[i] = NULL;
    }
+   memset(funcKeyInfo, 0, 13*sizeof(FuncKeyShortCutInfo));
+
    maxShortCuts = 0;
    if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "ShortCuts")) != NULL) {
-      int j, precise_match, ok, len;
-      unsigned int code;
-      char *saved_c_ptr, *tmp_c_ptr, *buf;
+      int j=0, precise_match=0, ok=0, len=0;
+      unsigned int code=0;
+      char *saved_c_ptr=NULL, *tmp_c_ptr=NULL, *buf=NULL;
 
       len = strlen(c_ptr);
       if ((buf=(char *)malloc((len+1)*sizeof(char))) == NULL) {
@@ -475,6 +518,8 @@ void InitShortCut()
             if (*tmp_c_ptr == '\0') {
                ok = FALSE;
             } else {
+               int func_index=0;
+
                if (*tmp_c_ptr == '\n') {
                   *tmp_c_ptr = '\0';
                } else {
@@ -484,7 +529,7 @@ void InitShortCut()
                if (buf[0] != '\0' && buf[1] == ':' &&
                      ((code>0x20 && code<=0x7f) || (code>0xa0 && code<=0xff))) {
                   int found=TRUE;
-                  char *paren_ptr;
+                  char *paren_ptr=NULL;
    
                   if ((paren_ptr=strchr(&buf[2], '(')) == NULL) {
                      fprintf(stderr,
@@ -494,7 +539,8 @@ void InitShortCut()
                   }
                   len = paren_ptr-(&buf[2]);
                   for (j=0; *(shortCutXlateTbl[j].name) != '\0'; j++) {
-                     if (strncmp(shortCutXlateTbl[j].name, &buf[2], len) == 0) {
+                     if (strncmp(shortCutXlateTbl[j].name, &buf[2], len) == 0 &&
+                           shortCutXlateTbl[j].name[len] == '(') {
                         if (shortCutXlateTbl[j].num_args != 0) {
                            shortCutArgs[code] = (char*)malloc(
                                  (strlen(&buf[len+2])+1)*sizeof(char));
@@ -586,6 +632,50 @@ void InitShortCut()
                            TgLoadString(STID_INVALID_SHORTCUT_ENTRY_SKIP), buf);
                      fprintf(stderr, "\n");
                   }
+               } else if (FunctionKeySpec(buf, &code, &func_index)) {
+                  int found=FALSE;
+                  char *paren_ptr=NULL;
+   
+                  if ((paren_ptr=strchr(&buf[func_index], '(')) == NULL) {
+                     fprintf(stderr,
+                           TgLoadString(STID_INVALID_SHORTCUT_ENTRY_SKIP), buf);
+                     fprintf(stderr, "\n");
+                     continue;
+                  }
+                  len = paren_ptr-(&buf[func_index]);
+                  for (j=0; *(shortCutXlateTbl[j].name) != '\0'; j++) {
+                     if (strncmp(shortCutXlateTbl[j].name, &buf[func_index],
+                           len) == 0 && shortCutXlateTbl[j].name[len] == '(') {
+                        if (funcKeyInfo[code].name != NULL) {
+                           fprintf(stderr,
+                                 TgLoadString(STID_DUP_SHORTCUT_FUNCTION_KEY),
+                                 code);
+                           fprintf(stderr, "\n");
+                        }
+                        funcKeyInfo[code].code = shortCutXlateTbl[j].code;
+                        funcKeyInfo[code].state = shortCutXlateTbl[j].state;
+                        funcKeyInfo[code].name =
+                              UtilStrDup(shortCutXlateTbl[j].name);
+                        if (funcKeyInfo[code].name == NULL) {
+                           FailAllocMessage();
+                        }
+                        if (shortCutXlateTbl[j].num_args != 0) {
+                           funcKeyInfo[code].arg = (char*)malloc(
+                                 (strlen(&buf[len+func_index])+1)*sizeof(char));
+                           if (funcKeyInfo[code].arg == NULL) {
+                              FailAllocMessage();
+                           }
+                           strcpy(funcKeyInfo[code].arg, ++paren_ptr);
+                        }
+                        found = TRUE;
+                        break;
+                     }
+                  }
+                  if (!found) {
+                     fprintf(stderr,
+                           TgLoadString(STID_INVALID_SHORTCUT_ENTRY_SKIP), buf);
+                     fprintf(stderr, "\n");
+                  }
                } else {
                   fprintf(stderr,
                         TgLoadString(STID_INVALID_SHORTCUT_ENTRY_SKIP), buf);
@@ -635,10 +725,14 @@ void CleanUpShortCut()
          free(shortCutArgs[i]);
       }
    }
+   for (i=0; i < 13; i++) {
+      UtilFree(funcKeyInfo[i].name);
+      UtilFree(funcKeyInfo[i].arg);
+   }
 }
 
-int FetchShortCut(c, code, state, name, args)
-   int c;
+int FetchShortCut(c, code, state, name, args, args_sz)
+   int c, args_sz;
    char *code, **name, *args;
    unsigned int *state;
 {
@@ -671,6 +765,49 @@ int FetchShortCut(c, code, state, name, args)
    return TRUE;
 }
 
+int FetchFuncKeyShortCut(c, code, state, name, args, args_sz)
+   int c, args_sz;
+   char *code, **name, *args;
+   unsigned int *state;
+{
+   int index=0;
+   char buf[MAXSTRING];
+
+   switch (c) {
+   case XK_F1: index=1; break;
+   case XK_F2: index=2; break;
+   case XK_F3: index=3; break;
+   case XK_F4: index=4; break;
+   case XK_F5: index=5; break;
+   case XK_F6: index=6; break;
+   case XK_F7: index=7; break;
+   case XK_F8: index=8; break;
+   case XK_F9: index=9; break;
+   case XK_F10: index=10; break;
+   case XK_F11: index=11; break;
+   case XK_F12: index=12; break;
+   default: return FALSE;
+   }
+   if (curChoice == DRAWTEXT) {
+      sprintf(buf, "DrawTextFuncKey_F%1d", index);
+      if (XGetDefault(mainDisplay, TOOL_NAME, buf) != NULL) {
+         return FALSE;
+      }
+   }
+   if (funcKeyInfo[index].name == NULL) return FALSE;
+
+   *code = funcKeyInfo[index].code;
+   *state = funcKeyInfo[index].state;
+   *name = funcKeyInfo[index].name;
+
+   if (funcKeyInfo[index].arg == NULL) {
+      *args = '\0';
+   } else {
+      strcpy(args, funcKeyInfo[index].arg);
+   }
+   return TRUE;
+}
+
 int FetchCmdById(nCmdId, code, state, name, args)
    int nCmdId;
    char *code, **name, *args;
