@@ -2,7 +2,7 @@
  * Author:      Daniel Ratton Figueiredo <ratton@land.ufrj.br>
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -29,7 +29,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tangram2.c,v 1.5 2005/01/15 00:23:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tangram2.c,v 1.8 2006/05/30 02:59:32 william Exp $
  */
 
 #define _INCLUDE_FROM_TANGRAM2_C_
@@ -437,7 +437,7 @@ void ExecStartSimulator(obj_ptr, orig_cmd)
         }
     
     if( (phe = gethostbyname( host )) != NULL )
-        bcopy( phe->h_addr, (char *)&sin.sin_addr, phe->h_length );
+        memcpy( (char *)&sin.sin_addr, phe->h_addr, phe->h_length );
     else
     {
         sin.sin_addr.s_addr = inet_addr( host );
@@ -501,7 +501,7 @@ void ExecStartSimulator(obj_ptr, orig_cmd)
     {
         sin_size = sizeof( sin );
         if( recvfrom( s, &buffer, sizeof(buffer), 0, (struct sockaddr *)&sin,
-                      &sin_size ) < 0 )
+                      (socklen_t *)(&sin_size) ) < 0 )
         {
             perror( "TGIF: recv" );
             return;
@@ -584,7 +584,6 @@ T_ControlPacket * ct_pack_in;
     int i;
     int begin, end;
     int alignment_size, name_length;
-    char *ptr;
     char line[ MAXSYMBOLNAME+MAXFORMATSIZE+MAXVALUESIZE ];
     char line_format[ MAXFORMATSIZE ];
     char var_value[ MAXSTRING + 1 ];
