@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgif.c,v 1.5 2005/01/15 00:23:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgif.c,v 1.8 2006/06/09 23:00:00 william Exp $
  */
 
 #define _INCLUDE_FROM_TGIF_C_
@@ -285,6 +285,7 @@ void PrTgifDump(inbuf, tile_page_err_msg_id)
    if (inbuf != NULL && strcmp(inbuf, "-") != 0) {
       UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), inbuf);
    }
+   if (cmdLineNoShowPageInEPS) showPageInEPS = FALSE;
    if (*cmdLineFileToExec != '\0') {
       if (!cmdLineQuiet) {
          fprintf(stderr, TgLoadString(STID_EXECUTING_GIVEN_SCRIPT),
@@ -347,7 +348,10 @@ void DoPrTgif(argc, argv, from_prtgif)
    }
    InitPaperSize();
    InitTmpDir();
-   if (PRTGIF && !cmdLineOpenDisplay) InitDontReencode(NULL);
+   if (PRTGIF && !cmdLineOpenDisplay) {
+      InitDontReencode(NULL);
+      InitPSFontCharSubs();
+   }
    if (*cmdLineGenParser != '\0') {
 #ifdef _TANGRAM_II
       InitNames();
