@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgtwb5.c,v 1.2 2005/01/15 00:23:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgtwb5.c,v 1.4 2006/05/30 02:56:28 william Exp $
  */
 
 #ifndef _NO_TGTWB5
@@ -118,7 +118,7 @@ int Tgtwb5_Init(dpy, win, arg)
    gZyfhInfo.zyfh_image_wh =
          round(((double)tgtwb5_width)/((double)gZyfhInfo.zyfh_num_cols));
    gZyfhInfo.zyfh_bitmap = XCreateBitmapFromData (mainDisplay, mainWindow,
-           tgtwb5_bits, tgtwb5_width, tgtwb5_height);
+           (char*)tgtwb5_bits, tgtwb5_width, tgtwb5_height);
 
    gZyfhInfo.symbol_bitmap = XCreatePixmap (mainDisplay, rootWindow,
          gZyfhInfo.zyfh_image_wh, gZyfhInfo.zyfh_image_wh, 1);
