@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2003, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/tgtwb5dl.c,v 4.30 2003/08/13 20:15:16 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgtwb5dl.c,v 1.4 2006/02/10 23:21:22 william Exp $
  */
 
 #ifndef _NO_TGTWB5
@@ -939,7 +939,7 @@ void InitTdgtb5DlgInfo(pti)
 
    pzdi->screen_w = DisplayWidth(mainDisplay, mainScreen);
    pzdi->screen_h = DisplayHeight(mainDisplay, mainScreen);
-   Tdgtb5DlgSetMsg("");
+   Tdgtb5DlgSetMsg(pti, "");
 
    pzdi->def_btn_id = BUTTON_OK;
    pzdi->double_click_btn_id = BUTTON_OK;
