@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgtwb5dl.c,v 1.2 2005/01/15 00:23:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgtwb5dl.c,v 1.4 2006/02/10 23:21:22 william Exp $
  */
 
 #ifndef _NO_TGTWB5
@@ -952,7 +952,7 @@ void InitTdgtb5DlgInfo(pti)
 
    pzdi->screen_w = DisplayWidth(mainDisplay, mainScreen);
    pzdi->screen_h = DisplayHeight(mainDisplay, mainScreen);
-   Tdgtb5DlgSetMsg("");
+   Tdgtb5DlgSetMsg(pti, "");
 
    pzdi->def_btn_id = BUTTON_OK;
    pzdi->double_click_btn_id = BUTTON_OK;
