@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/types.h,v 1.2 2005/01/15 00:23:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/types.h,v 1.7 2006/06/11 20:36:58 william Exp $
  */
 
 #ifndef _TGIF_TYPES_H_
@@ -486,7 +486,10 @@ typedef struct XBmRec {
 } * XBmRecPtr;
 
 typedef struct XPmRec {
-   int			fill, flip, image_w, image_h;
+   int			fill, real_type, flip, image_w, image_h;
+   int			linked_jpeg; /* TRUE if JPEG is linked */
+   char			* filename; /* only valid if JPEG is linked */
+   char			tmp_ppm6_fname[MAXPATHLENGTH+1]; /* only valid if JPEG is linked */
    int			ncolors;
    int			chars_per_pixel;
    int			first_pixel_is_bg;
