@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/util.c,v 1.3 2005/01/15 00:23:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/util.c,v 1.5 2006/06/09 23:00:00 william Exp $
  */
 
 #define _INCLUDE_FROM_UTIL_C_
@@ -226,6 +226,55 @@ char *UtilStrRChr(pszStr, int_ch)
    return NULL;
 }
 
+char *UtilStrTok(pszStr, pszDelim, ppszState)
+   char *pszStr, *pszDelim, **ppszState;
+{
+   char *psz=NULL, *psz_start=NULL;
+
+   if (pszStr != NULL) {
+      *ppszState = NULL;
+      psz_start = pszStr;
+      while (*psz_start != '\0' && strchr(pszDelim, *psz_start) != NULL) {
+         psz_start++;
+      }
+      if (*psz_start == '\0') return NULL;
+
+      for (psz=psz_start; *psz != '\0'; psz++) {
+         if (strchr(pszDelim, *psz) != NULL) {
+            *psz = '\0';
+            *ppszState = psz;
+
+            return psz_start;
+         }
+      }
+      if (*psz == '\0' && psz_start != psz) {
+         return psz_start;
+      }
+   } else {
+      if (*ppszState == NULL) return NULL;
+
+      psz_start = &(*ppszState)[1];
+      *ppszState = NULL;
+      while (*psz_start != '\0' && strchr(pszDelim, *psz_start) != NULL) {
+         psz_start++;
+      }
+      if (*psz_start == '\0') return NULL;
+
+      for (psz=psz_start; *psz != '\0'; psz++) {
+         if (strchr(pszDelim, *psz) != NULL) {
+            *psz = '\0';
+            *ppszState = psz;
+
+            return psz_start;
+         }
+      }
+      if (*psz == '\0' && psz_start != psz) {
+         return psz_start;
+      }
+   }
+   return NULL;
+}
+
 #ifdef NO_STRSTR
 char *strstr (pszStr, pszSubStr)
    char *pszStr, *pszSubStr;
