@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2005, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2006, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/version.c,v 1.2 2005/01/15 00:23:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/version.c,v 1.6 2006/05/30 01:59:41 william Exp $
  */
 
 #define _INCLUDE_FROM_VERSION_C_
@@ -41,17 +41,17 @@
 char *versionString="4.1";
 char *authorEmailString="bill.cheng@acm.org";
 #ifdef QPL_LICENSE
-char *copyrightString="Copyright (C) 2001-2003, William Chia-Wei Cheng";
+char *copyrightString="Copyright (C) 2001-2006, William Chia-Wei Cheng";
 #else /* ~QPL_LICENSE */
-char *copyrightString="Copyright (C) 1990-2003, William Chia-Wei Cheng";
+char *copyrightString="Copyright (C) 1990-2006, William Chia-Wei Cheng";
 #endif /* QPL_LICENSE */
-char *homePageURL="http://bourbon.usc.edu:8001/tgif/";
+char *homePageURL="http://bourbon.usc.edu/tgif/";
 char *oldMailingList="kragen-tgif@kragen.dnaco.net";
 char *mailingList="tgif4-announce@yahoogroups.com";
 char *joinMailingList="tgif4-announce-subscribe@yahoogroups.com";
-char *mailingURL="http://bourbon.usc.edu:8001/tgif/faq/mailings.html";
-char *currentReleaseURL="http://bourbon.usc.edu:8001/tgif/download.html";
-char *hyperGraphicsURL="http://bourbon.usc.edu:8001/tgif/index.obj";
+char *mailingURL="http://bourbon.usc.edu/tgif/faq/mailings.html";
+char *currentReleaseURL="http://bourbon.usc.edu/tgif/download.html";
+char *hyperGraphicsURL="http://bourbon.usc.edu/tgif/index.obj";
 
 char fullVersionString[MAXSTRING];
 char fullToolName[MAXSTRING];
